OC.L10N.register(
    "circles",
    {
    "Circles" : "Körök",
    "Circles' files" : "Kör fájljai",
    "Select circles to filter by" : "Válasszon köröket a szűréshez",
    "No circles found" : "Nincsenek körök",
    "Please select circles to filter by" : "Válasszon köröket a szűréshez",
    "No files found for the selected circles" : "Nem találhatók fájlok a kiválasztott körökhöz",
    "You created the circle {circle}" : "Létrehozta a(z) {circle} kört",
    "{author} created the circle {circle}" : "{author} létrehozta a(z) {circle} kört",
    "You deleted {circle}" : "Törölte ezt: {circle}",
    "{author} deleted {circle}" : "{author} törölte a(z) {circle} kört",
    "You linked {group} to {circle}" : "Hozzákapcsolta a(z) {group} csoportot ehhez: {circle}",
    "{group} has been linked to {circle} by {author}" : "{author} hozzákapcsolta a(z) {group} csoportot ehhez a körhöz: {circle}",
    "You unlinked {group} from {circle}" : "Leválasztotta a(z) {group} csoportot a(z) {circle} körről",
    "{group} has been unlinked from {circle} by {author}" : "{author} leválasztott a(z) {group} csoportot a(z) {circle}",
    "You changed the level of the linked group {group} in {circle} to %1$s" : "Megváltoztatta a kapcsolt {group} csoport szintjét a(z) {circle} körben erre: %1$s",
    "{author} changed the level of the linked group {group} in {circle} to %1$s" : "{author} megváltoztatta a kapcsolt {group} csoport szintjét a {circle} körben erre: %1$s",
    "You sent a request to link {circle} with {remote}" : "Kérést küldött, hogy összekapcsolja a(z) {circle} kört ezzel: {remote}",
    "{author} sent a request to link {circle} with {remote}" : "{author} kérést küldött, hogy összekapcsolja a(z) {circle} kört ezzel: {remote}",
    "{remote} requested a link with {circle}" : "{remote} összekapcsolást kért a(z) {circle} körrel",
    "The request to link {circle} with {remote} has been rejected" : "A kérés, hogy a(z) {remote} hozzá legyen kapcsolva a(z) {circle} körhöz, elutasításra került",
    "The request to link {remote} with {circle} has been canceled remotely" : "A kérés, hogy a(z) {remote} hozzá legyen kapcsolva a(z) {circle} körhöz, visszavonásra került",
    "The request to link {circle} with {remote} has been accepted" : "A kérés, hogy a(z) {remote} hozzá legyen kapcsolva a(z) {circle} körhöz, elfogadásra került",
    "You dismissed the request to link {remote} with {circle}" : "Visszautasította, hogy a(z) {remote} hozzá legyen kapcsolva a(z) {circle} körhöz",
    "{author} dismissed the request to link {remote} with {circle}" : "{author} visszautasította, hogy a(z) {remote} hozzá legyen kapcsolva a(z) {circle} körhöz",
    "You canceled the request to link {circle} with {remote}" : "Visszavonta, hogy a(z) {remote} hozzá legyen kapcsolva a(z) {circle} körhöz",
    "{author} canceled the request to link {circle} with {remote}" : "{author} visszavonta, hogy a(z) {remote} hozzá legyen kapcsolva a(z) {circle} körhöz",
    "You accepted the request to link {remote} with {circle}" : "Elfogadta, hogy a(z) {remote} hozzá legyen kapcsolva a(z) {circle} körhöz",
    "{author} accepted the request to link {remote} with {circle}" : "{author} elfogadta, hogy a(z) {remote} hozzá legyen kapcsolva a(z) {circle} körhöz",
    "A link between {circle} and {remote} is now up and running" : "A(z) {circle} és a(z) {remote} közötti kapcsolat létrejött és működik",
    "The link between {circle} and {remote} has been shutdown remotely" : "A(z) {circle} és a(z) {remote} közötti kapcsolat távolról megszakítva",
    "You closed the link between {circle} and {remote}" : "Lezárta a(z) {circle} és a(z) {remote} közötti kapcsolatot",
    "{author} closed the link between {circle} and {remote}" : "{author} lezárta a(z) {circle} és a(z) {remote} közötti kapcsolatot",
    "You joined {circle}" : "Csatlakozott ehhez: {circle}",
    "{member} joined {circle}" : "{member} csatlakozott ehhez: {circle}",
    "You accepted the invitation to join {circle}" : "Elfogadta a meghívást, hogy csatlakozzon a(z) {circle} körhöz",
    "{member} accepted the invitation to join {circle}" : "{member} elfogadta a meghívást, hogy csatlakozzon a(z) {circle} körhöz",
    "You added {member} as member to {circle}" : "Hozzáadta tagként a következőt a(z) {circle} körhöz: {member}",
    "You have been added as member to {circle} by {author}" : "{author} hozzáadta tagként a(z) {circle} körhöz",
    "{member} has been added as member to {circle} by {author}" : "{author} hozzáadta tagként a következőt a(z) {circle} körhöz: {member}",
    "You added {external} to {circle}" : "Hozzáadta a következőt a(z) {circle} körhöz: {external}",
    "{external} has been added to {circle} by {author}" : "{author} hozzáadta a következőt a(z) {circle} körhöz: {external}",
    "You accepted {member}'s request to join {circle}" : "Elfogadta {member} kérését, hogy csatlakozzon a(z) {circle} körhöz",
    "Your request to join {circle} has been accepted by {author}" : "{author} elfogadta a kérését, hogy csatlakozzon a(z) {circle} körhöz",
    "{member}'s request to join {circle} has been accepted by {author}" : "{author} elfogadta {member} kérését, hogy csatlakozzon a(z) {circle} körhöz",
    "You left {circle}" : "Elhagyta a(z) {circle} kört",
    "{member} left {circle}" : "{member} elhagyta a(z) {circle} kört",
    "You declined the invitation to join {circle}" : "Visszautasította a meghívást, hogy csatlakozzon a(z) {circle} körbe",
    "{member} declined an invitation to join {circle}" : "{member} visszautasította a meghívást, hogy csatlakozzon a(z) {circle} körbe",
    "You cancelled your request to join {circle}" : "Visszavonta a kérését, hogy csatlakozzon a(z) {circle} körhöz",
    "{member} cancelled his request to join {circle}" : "{member} visszavonta a kérését, hogy csatlakozzon a(z) {circle} körhöz",
    "You removed {member} from {circle}" : "Eltávolította {member} tagot a(z) {circle} körből",
    "You have been removed from {circle} by {author}" : "{author} eltávolította a(z) {circle} körből",
    "{member} has been removed from {circle} by {author}" : "{author} eltávolította {member} tagot a(z) {circle} körből",
    "You removed {external} from {circle}" : "Eltávolította a következőt a(z) {circle} körből: {external}",
    "{external} has been removed from {circle} by {author}" : "{external} eltávolította a következőt a(z) {circle} körből: {external}",
    "You cancelled {member}'s invitation to join {circle}" : "Visszavonta {member} meghívását a(z) {circle} körbe",
    "Your invitation to join {circle} has been cancelled by {author}" : "{author} visszavonta a(z) {circle} körbe való meghívását",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} visszavonta {member} meghívását a(z) {circle} körbe",
    "You dismissed {member}'s request to join {circle}" : "Elutasította {member} kérését, hogy csatlakozzon a(z) {circle} körhöz",
    "Your request to join {circle} has been dismissed by {author}" : "{author} elutasította a kérését, hogy csatlakozzon a(z) {circle} körhöz",
    "{member}'s request to join {circle} has been dismissed by {author}" : "{author} elutasította {member} kérését, hogy csatlakozzon a(z) {circle} körhöz",
    "You invited {member} to join {circle}" : "Meghívta {member} tagot, hogy csatlakozzon a(z) {circle} körhöz",
    "You have been invited to join {circle} by {author}" : "{author} meghívta, hogy csatlakozzon a(z) {circle} körhöz",
    "{member} has been invited to join {circle} by {author}" : "{author} meghívta {member} tagot, hogy csatlakozzon a(z) {circle} körhöz",
    "You changed {member}'s level in {circle} to %1$s" : "Megváltoztatta {member} szintjét a(z) {circle} körben erre: %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} megváltoztatta az Ön szintjét a(z) {circle} körben erre: %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} megváltoztatta {member} szintjét a(z) {circle} körben erre: %1$s",
    "You sent a request to join {circle}" : "Kérést küldött, hogy csatlakozhasson a(z) {circle} körhöz",
    "{member} sent a request to join {circle}" : "{member} kérte, hogy csatlakozhasson a(z) {circle} körhöz",
    "You are the new owner of {circle}" : "Ön a(z) {circle} kör új tulajdonosa",
    "{member} is the new owner of {circle}" : "{member} a(z) {circle} kör új tulajdonosa",
    "On events happening in a <strong>Circle</strong> of which you are a member" : "Olyan eseményekről, amelyek olyan <strong>körben</strong> zajlanak, amelynek tagja",
    "Any important event in a <strong>Circle</strong> you are moderating" : "Bármely fontos eseményről, amely olyan <strong>körben</strong> történt, melyeket moderál",
    "On global events happening in any <strong>Circle</strong>" : "Bármely <strong>körben</strong> zajló globális eseményekről",
    "Shared to Circles" : "Körökkel megosztva",
    "Single" : "Egyéni",
    "Personal" : "Személyes",
    "System" : "Rendszer",
    "Visible" : "Látható",
    "Open" : "Nyílt",
    "Invite" : "Meghívás",
    "Join Request" : "Csatlakozási kérés",
    "Friends" : "Barátok",
    "Password Protected" : "Jelszóval védett",
    "No Owner" : "Tulajdonos nélküli",
    "Hidden" : "Rejtett",
    "Backend" : "Háttérprogram",
    "Local" : "Helyi",
    "Root" : "Gyökér",
    "Circle Invite" : "Meghívás körbe",
    "Federated" : "Föderált",
    "Mount point" : "Csatolási pont",
    "Nextcloud Account" : "Nextcloud-fiók",
    "Nextcloud Group" : "Nextcloud csoport",
    "Email Address" : "E-mail-cím",
    "Contact" : "Névjegy",
    "Circle" : "Kör",
    "Nextcloud App" : "Nextcloud alkalmazás",
    "Member" : "Tag",
    "Moderator" : "Moderátor",
    "Admin" : "Rendszergazda",
    "Owner" : "Tulajdonos",
    "%s shared »%s« with you." : "%s megosztotta Önnel: »%s«.",
    "%s shared »%s« with \"%s\"." : "%s megosztotta ezt: »%s« a következővel: „%s”.",
    "%s on %s" : "%s ezen: %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s megosztotta Önnel: »%2$s«.\nMár meg kellett volna kapnia a különálló e-mailt, amely a hozzáféréshez szükséges hivatkozást tartalmazza.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s megosztotta Önnel: »%2$s«. Már meg kellett volna kapnia a különálló e-mailt, amely a hozzáféréshez szükséges hivatkozást tartalmazza.",
    "Password to access »%1$s« shared to you by %2$s" : "Jelszó a(z) %2$s által megosztott »%1$s« eléréséhez",
    "Password to access »%s«" : "Jelszó »%s« eléréséhez",
    "It is protected with the following password:" : "A következő jelszóval védve:",
    "%1$s via %2$s" : "%1$s-tól %2$s-ig",
    "Click the button below to open it." : "Kattintson a lenti gombra a megnyitáshoz.",
    "Open »%s«" : "»%s« megnyitása",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s több fájlt osztott meg Önnel.\nMár meg kellett volna kapnia a különálló e-mailt, amely a hozzáféréshez szükséges hivatkozást tartalmazza.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s több fájlt osztott meg Önnel. Már meg kellett volna kapnia a különálló e-mailt, amely a hozzáféréshez szükséges hivatkozást tartalmazza.",
    "Password to access files shared to you by %1$s" : "Jelszó a(z) %1$s által megosztott fájlok eléréséhez",
    "Password to access files" : "Jelszó a fájlok eléréséhez",
    "%s shared multiple files with \"%s\"." : "%s több fájlt osztott a következővel: „%s”.",
    "%s shared multiple files with you." : "%s több fájlt osztott meg Önnel.",
    "Boot up" : "Rendszerindítás",
    "Nextcloud Initialization" : "A Nextcloud előkészítése",
    "Circles App Initialization" : "Körök alkalmazás előkészítése",
    "Fresh installation status" : "Friss előkészítési állapot",
    "Building Local Database" : "Helyi adatbázis építése",
    "Testing Basic Circle Creation" : "Alapvető körlétrehozás tesztelése",
    "Adding local users and moderators" : "Helyi felhasználók és moderátorok hozzáadása",
    "Circle not found" : "A Kör nem található",
    "Circle not found " : "A Kör nem található ",
    "This member does not exist" : "Ez a tag nem létezik",
    "This account is already a member of the circle" : "A fiók már tagja a körnek",
    "Federated link not found" : "A föderált kapcsolat nem található",
    "This feature is not available for personal circles" : "Ez a szolgáltatás nem elérhető a személyes köröknél",
    "The circle is not federated" : "A kör nem föderált",
    "You cannot join this circle" : "Nem csatlakozhat ehhez a körhöz",
    "This member is not a moderator" : "Ez a tag nem moderátor",
    "Insufficient privileges" : "Elégtelen jogosultság",
    "This member is the owner of the circle" : "Ez a tag a kör tulajdonosa",
    "Level cannot be changed for this type of member" : "Az ilyen típusú tag szintje nem változtatható meg",
    "You are already a member of this circle" : "Ön már tagja ennek a körnek",
    "You have been blocked from this circle" : "Kizárták ebből a körből",
    "The account is already a member of this circle" : "A fiók már tagja e körnek",
    "The account has already been invited into this circle" : "A fiók már meg lett hívva a körbe",
    "%s (Circle owned by %s)" : "%s (A kör tulajdonosa %s)",
    "You are now a member of the Circle \"%2$s\"" : "Ön most már a(z) „%2$s” kör tagja",
    "You have been invited by %1$s into the Circle \"%2$s\"" : "%1$s meghívta Önt a (z) „\"%2$s” körbe",
    "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$s csatlakozási kérést küldött, hogy a(z) „%2$s\" kör tagja lehessen",
    "Accept" : "Elfogadás",
    "Refuse" : "Elutasítás",
    "Leave the circle" : "Kör elhagyása",
    "%s" : "%s",
    "Personal Circle" : "Személyes kör",
    "%s owned by %s" : "a(z) %s tulajdonosa %s",
    "You need a specify a type of circle" : "Meg kell adnia egy körtípust",
    "A circle with that name exists" : "Már van ilyen nevű kör",
    "This member is not the owner of the circle" : "Ez a tag nem a kör tulajdonosa",
    "This member is not an admin of the circle" : "Ez a tag nem a kör adminisztrátora",
    "Group contains too many members" : "A csoport túl sok tagot tartalmaz",
    "This group does not exist" : "Ez a csoport nem létezik",
    "This group is already linked to the circle" : "Ez a csoport már hozzá van kapcsolva a körhöz",
    "You cannot edit level in a personal circle" : "A szint nem szerkeszthető egy személyes körnél",
    "Group cannot be set as owner of a circle" : "Csoport nem lehet kör tulajdonosa",
    "now" : "most",
    "This account does not exist" : "A fiók nem létezik",
    "Email format is not valid" : "Az e-mail formátum érvénytelen",
    "This contact is not available" : "A névjegy nem érhető el",
    "You have no permission to create a new circle" : "Nincs jogosultsága arra, hogy új kört hozzon létre",
    "%s shared a file with \"%s\"." : "%s megosztott egy fájlt a következővel: „%s”.",
    "%s shared a file with you." : "%s megosztott egy fájlt Önnel.",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s tartalmat osztott meg Önnel.\nMár meg kellett volna kapnia a különálló e-mailt, amely a hozzáféréshez szükséges hivatkozást tartalmazza.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s tartalmat osztott meg Önnel. Már meg kellett volna kapnia a különálló e-mailt, amely a hozzáféréshez szükséges hivatkozást tartalmazza.",
    "Password to access content shared with you by %1$s" : "Jelszó a(z) %1$s által megosztott tartalom eléréséhez",
    "Password to access content" : "Jelszó a tartalom eléréséhez",
    "This item is already shared with this circle" : "Ez az elem már megosztásra került ezzel a körrel",
    "Bring cloud-users closer together." : "Közelebb hozza a felhőfelhasználókat.",
    "Circles allows people to create their own groups of people/colleagues/friends.\nThose groups of people (or \"circles\") can then be used by any other app for sharing purpose." : "A Körök lehetővé teszi, hogy az emberek létrehozzák a saját köreiket a felhasználóinak/kollégáinak/barátaiknak.\nEzeket a csoportokat (vagy „köröket”) aztán bármely más alkalmazás használhatja megosztási célokra.",
    "No files in here" : "Itt nincsenek fájlok",
    "No entries found in this folder" : "Nincsenek bejegyzések ebben a mappában",
    "Name" : "Név",
    "Size" : "Méret",
    "Modified" : "Módosítva",
    "Initialisation Nextcloud" : "A Nextcloud előkészítése",
    "Initialisation Circles App" : "A Körök alkalmazás előkészítése",
    "You cannot use the Circles Application until your administrator has allowed at least one type of circles" : "A Körök alkalmazás nem használható, amíg a rendszergazda legalább egy körtípust nem engedélyez.",
    "Could not find share" : "A megosztás nem található"
},
"nplurals=2; plural=(n != 1);");
